<?php
//require_once 'TeknisaEvaluator.php';

/**
 * FolhaEvaluator.
 *
 * @package Logic
 * @author  alessandrobartels / brunofeliciano - 12/08/2011
 */
class FolhaEvaluator extends TeknisaEvaluator{

    private $_calculoRegra;
    private $_calculo;
    private $_mnemonicos;

    /**
     * Construtor.
     *
     * @param CalculoRegra $calculo_regra Instancia de CalculoRegra.
     */
    public function __construct(CalculoRegra $calculo_regra){
        $calculoRegra = new TeknisaRegra($calculo_regra);
        parent::__construct($calculoRegra);
        $this->_calculoRegra = $calculo_regra;

        $this->_inicializaAtributos();

        /* $this->_declaraVariaveisFolha(); */
        $this->_declaraRegrasFolha();
    }


    /**
     * Inicializa atributos.
     *
     * @return void
     *
     * @author  alessandrobartels / brunofeliciano - 18/08/2011
     */
    private function _inicializaAtributos(){
        $this->_calculo = $this->_calculoRegra->getCalculo();
    }


    /**
     * Declaracao das Regras.
     *
     * @return void
     */
    private function _declaraRegrasFolha(){
        $this->_mnemonicos = array(
            'SE' => array($this->_calculoRegra, 'retornaValorPorCondicao', array('condicao', 'valorSeVerdadeiro', 'valorSeFalso')),
            'DIAS_NORM'=> array($this->_calculo, 'getDiasNormais','',array()),
            'DIAS_TRAB'=> array($this->_calculo, 'getDiasTrabalhados','',array()),
            'DIAS_REM'=> array($this->_calculo, 'getDiasRemuneracao','',array()),
            'DIAS_FER'=> array($this->_calculo, 'getDiasFerias','',array()),
            'ATRIB_VAL'=> array($this->_calculoRegra, 'atribuiValor', array('valor')),
            'ATRIB_REF'=> array($this->_calculoRegra, 'atribuiReferencia', array('referencia')),
            'ATRIB_OCOR'=> array($this->_calculoRegra, 'atribuiOcorrencias', array('ocorrencias')),
            'VAL_EVEN'=> array($this->_calculoRegra, 'retornaValorEvento', array('nr_evento')),
            'REF_EVEN'=> array($this->_calculoRegra, 'retornaReferenciaEvento', array('nr_evento')),
            'EXISTE_EVEN'=> array($this->_calculoRegra, 'verificaExistenciaEvento', array('nr_evento')),
            'VAL_INCID'=> array($this->_calculoRegra, 'retornaValorIncidencia', array('nr_incidencia')),
            'REF_INCID'=> array($this->_calculoRegra, 'retornaReferenciaIncidencia', array('nr_incidencia')),
            'DADOS_VINC'=> array($this->_calculoRegra, 'retornaDadosVinculo', array('nomeColuna')),
            'TOTAL_VAL'=> array($this->_calculoRegra, 'totalizaValorHistorico',array('listaNrEvento', 'nrTipoMovimento', 'deslocamento', 'mesIncidencia')),
            'TOTAL_REF'=> array($this->_calculoRegra, 'totalizaReferenciaHistorico',array('listaNrEvento', 'nrTipoMovimento', 'deslocamento', 'mesIncidencia')),
            'TOTAL_PARC'=> array($this->_calculoRegra, 'totalizaOcorrenciaHistorico',array('listaNrEvento', 'nrTipoMovimento', 'deslocamento', 'mesIncidencia')),
            'DIAS_ENTRE' => array($this->_calculoRegra, "getDiasEntre", array("dataInicial", "dataFinal")),
            'DT_COMPETEN' => array($this->_calculoRegra, "getDataCompetencia"),
            'TOMADOR' => array($this->_calculoRegra, "getTomador", array("nrestrutgeren")),
            'DIAS_REAIS' => array($this->_calculoRegra, "getDiasCompetencia"),
            'DIAS_DSR'=> array($this->_calculo, 'getDiasDSR','',array()),			
            'SALARIO'=> array($this->_calculo, 'getSalario','',array()),
            'JORNADA_DIA'=> array($this->_calculo, 'getJornadaDiaria','',array()),
            'ULT_DIA_COMP'=> array($this->_calculoRegra, 'getUltimoDiaMes'),		
        );



        foreach($this->_mnemonicos as $mnemonico => $value){
            $this->setObjectFunction($mnemonico, $value[0], $value[1],$value[2]);
        }
    }


}